Installation
------------
You can install py-romanify with ``pip``:

.. code-block:: console

    $ pip install py-romanify

Or from ``git``:

.. code-block:: console

    $ git clone https://github.com/peter-lisak/py-romanify.git
    $ python setup.py install
